@@ -1,12 +1,11 @@
-from typing import Any, Literal, NotRequired, TypedDict
+from typing import Any, Literal, NotRequired
 
-from lsp.lsp.common import (CodeActionKind, EmptyDict, FailureHandlingKind,
-                            FoldingRangeKind, InsertTextMode, MarkupKind,
-                            PositionEncodingKind, ResourceOperationKind,
-                            SymbolKind, SymbolTag, TokenFormat)
+from lsp.lsp.common import (CodeActionKind, EmptyDict, FailureHandlingKind, FoldingRangeKind, InsertTextMode,
+                            MarkupKind, MessageData, PositionEncodingKind, ResourceOperationKind, SymbolKind, SymbolTag,
+                            TokenFormat)
 
 
-class ClientWorkspaceCapabilitiesFileOptions(TypedDict):
+class ClientWorkspaceCapabilitiesFileOptions(MessageData):
     #
     # Whether the client supports dynamic registration for file
     # requests/notifications.
@@ -44,7 +43,7 @@ class ClientWorkspaceCapabilitiesFileOptions(TypedDict):
     willDelete: NotRequired[bool]
 
 
-class WorkspaceEditClientCapabilitiesChangeAnnotationSupport(TypedDict):
+class WorkspaceEditClientCapabilitiesChangeAnnotationSupport(MessageData):
     #
     # Whether the client groups edits with equal labels into tree nodes,
     # for instance all edits labelled with "Changes in Strings" would
@@ -53,7 +52,7 @@ class WorkspaceEditClientCapabilitiesChangeAnnotationSupport(TypedDict):
     groupsOnLabel: NotRequired[bool]
 
 
-class WorkspaceEditClientCapabilities(TypedDict):
+class WorkspaceEditClientCapabilities(MessageData):
     #
     # The client supports versioned document changes in `WorkspaceEdit`s
     #
@@ -87,18 +86,17 @@ class WorkspaceEditClientCapabilities(TypedDict):
     # create file, rename file and delete file changes.
     # @since 3.16.0
     #
-    changeAnnotationSupport: NotRequired[
-        WorkspaceEditClientCapabilitiesChangeAnnotationSupport]
+    changeAnnotationSupport: NotRequired[WorkspaceEditClientCapabilitiesChangeAnnotationSupport]
 
 
-class DidChangeConfigurationClientCapabilities(TypedDict):
+class DidChangeConfigurationClientCapabilities(MessageData):
     #
     # Did change configuration notification supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class DidChangeWatchedFilesClientCapabilities(TypedDict):
+class DidChangeWatchedFilesClientCapabilities(MessageData):
     #
     # Did change watched files notification supports dynamic registration.
     # Please note that the current protocol doesn't support static
@@ -115,7 +113,7 @@ class DidChangeWatchedFilesClientCapabilities(TypedDict):
     relativePatternSupport: NotRequired[bool]
 
 
-class WorkspaceSymbolClientCapabilitiesSymbolKind(TypedDict):
+class WorkspaceSymbolClientCapabilitiesSymbolKind(MessageData):
     #
     # The symbol kind values the client supports. When this
     # property exists the client also guarantees that it will
@@ -129,14 +127,14 @@ class WorkspaceSymbolClientCapabilitiesSymbolKind(TypedDict):
     valueSet: NotRequired[list[SymbolKind]]
 
 
-class WorkspaceSymbolClientCapabilitiesTagSupport(TypedDict):
+class WorkspaceSymbolClientCapabilitiesTagSupport(MessageData):
     #
     # The tags supported by the client.
     #
     valueSet: list[SymbolTag]
 
 
-class WorkspaceSymbolClientCapabilitiesResolveSupport(TypedDict):
+class WorkspaceSymbolClientCapabilitiesResolveSupport(MessageData):
     #
     # The properties that a client can resolve lazily. Usually
     # `location.range`
@@ -144,7 +142,7 @@ class WorkspaceSymbolClientCapabilitiesResolveSupport(TypedDict):
     properties: list[str]
 
 
-class WorkspaceSymbolClientCapabilities(TypedDict):
+class WorkspaceSymbolClientCapabilities(MessageData):
     #
     # Symbol request supports dynamic registration.
     #
@@ -171,18 +169,17 @@ class WorkspaceSymbolClientCapabilities(TypedDict):
     #
     # @since 3.17.0 - proposedState
     #
-    resolveSupport: NotRequired[
-        WorkspaceSymbolClientCapabilitiesResolveSupport]
+    resolveSupport: NotRequired[WorkspaceSymbolClientCapabilitiesResolveSupport]
 
 
-class ExecuteCommandClientCapabilities(TypedDict):
+class ExecuteCommandClientCapabilities(MessageData):
     #
     # Execute command supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class SemanticTokensWorkspaceClientCapabilities(TypedDict):
+class SemanticTokensWorkspaceClientCapabilities(MessageData):
     #
     # Whether the client implementation supports a refresh request sent from
     # the server to the client.
@@ -195,7 +192,7 @@ class SemanticTokensWorkspaceClientCapabilities(TypedDict):
     refreshSupport: NotRequired[bool]
 
 
-class CodeLensWorkspaceClientCapabilities(TypedDict):
+class CodeLensWorkspaceClientCapabilities(MessageData):
     #
     # Whether the client implementation supports a refresh request sent from the
     # server to the client.
@@ -208,7 +205,7 @@ class CodeLensWorkspaceClientCapabilities(TypedDict):
     refreshSupport: NotRequired[bool]
 
 
-class InlineValueWorkspaceClientCapabilities(TypedDict):
+class InlineValueWorkspaceClientCapabilities(MessageData):
     #
     # Whether the client implementation supports a refresh request sent from
     # the server to the client.
@@ -222,7 +219,7 @@ class InlineValueWorkspaceClientCapabilities(TypedDict):
     refreshSupport: NotRequired[bool]
 
 
-class InlayHintWorkspaceClientCapabilities(TypedDict):
+class InlayHintWorkspaceClientCapabilities(MessageData):
     #
     # Whether the client implementation supports a refresh request sent from
     # the server to the client.
@@ -235,7 +232,7 @@ class InlayHintWorkspaceClientCapabilities(TypedDict):
     refreshSupport: NotRequired[bool]
 
 
-class DiagnosticWorkspaceClientCapabilities(TypedDict):
+class DiagnosticWorkspaceClientCapabilities(MessageData):
     #
     # Whether the client implementation supports a refresh request sent from
     # the server to the client.
@@ -248,7 +245,7 @@ class DiagnosticWorkspaceClientCapabilities(TypedDict):
     refreshSupport: NotRequired[bool]
 
 
-class ClientWorkspaceCapabilities(TypedDict):
+class ClientWorkspaceCapabilities(MessageData):
     #
     # The client supports applying batch edits
     # to the workspace by supporting the request
@@ -263,8 +260,7 @@ class ClientWorkspaceCapabilities(TypedDict):
     # Capabilities specific to the `workspace/didChangeConfiguration`
     # notification.
     #
-    didChangeConfiguration: NotRequired[
-        DidChangeConfigurationClientCapabilities]
+    didChangeConfiguration: NotRequired[DidChangeConfigurationClientCapabilities]
     #
     # Capabilities specific to the `workspace/didChangeWatchedFiles`
     # notification.
@@ -322,7 +318,7 @@ class ClientWorkspaceCapabilities(TypedDict):
     diagnostics: NotRequired[DiagnosticWorkspaceClientCapabilities]
 
 
-class ShowMessageRequestClientCapabilitiesMessageActionItem(TypedDict):
+class ShowMessageRequestClientCapabilitiesMessageActionItem(MessageData):
     #
     # Whether the client supports additional attributes which
     # are preserved and sent back to the server in the
@@ -331,19 +327,18 @@ class ShowMessageRequestClientCapabilitiesMessageActionItem(TypedDict):
     additionalPropertiesSupport: NotRequired[bool]
 
 
-class ShowMessageRequestClientCapabilities(TypedDict):
+class ShowMessageRequestClientCapabilities(MessageData):
     #
     # Capabilities specific to the `MessageActionItem` type.
     #
-    messageActionItem: NotRequired[
-        ShowMessageRequestClientCapabilitiesMessageActionItem]
+    messageActionItem: NotRequired[ShowMessageRequestClientCapabilitiesMessageActionItem]
 
 
-class ShowDocumentClientCapabilities(TypedDict):
+class ShowDocumentClientCapabilities(MessageData):
     support: bool
 
 
-class ClientCapabilitiesWindow(TypedDict):
+class ClientCapabilitiesWindow(MessageData):
 
     #
     # It indicates whether the client supports server initiated
@@ -369,7 +364,7 @@ class ClientCapabilitiesWindow(TypedDict):
     showDocument: NotRequired[ShowDocumentClientCapabilities]
 
 
-class ClientCapabilitiesGeneralStaleRequestSupport(TypedDict):
+class ClientCapabilitiesGeneralStaleRequestSupport(MessageData):
     #
     # The client will actively cancel the request.
     #
@@ -383,7 +378,7 @@ class ClientCapabilitiesGeneralStaleRequestSupport(TypedDict):
     retryOnContentModified: list[str]
 
 
-class RegularExpressionsClientCapabilities(TypedDict):
+class RegularExpressionsClientCapabilities(MessageData):
     #
     # The engine's name.
     #
@@ -395,7 +390,7 @@ class RegularExpressionsClientCapabilities(TypedDict):
     version: NotRequired[str]
 
 
-class MarkdownClientCapabilities(TypedDict):
+class MarkdownClientCapabilities(MessageData):
     #
     # The name of the parser.
     #
@@ -415,7 +410,7 @@ class MarkdownClientCapabilities(TypedDict):
     allowedTags: NotRequired[list[str]]
 
 
-class ClientCapabilitiesGeneral(TypedDict):
+class ClientCapabilitiesGeneral(MessageData):
     #
     # Client capability that signals how the client
     # handles stale requests (e.g. a request
@@ -423,8 +418,7 @@ class ClientCapabilitiesGeneral(TypedDict):
     # anymore since the information is outdated).
     # @since 3.17.0
     #
-    staleRequestSupport: NotRequired[
-        ClientCapabilitiesGeneralStaleRequestSupport]
+    staleRequestSupport: NotRequired[ClientCapabilitiesGeneralStaleRequestSupport]
 
     #
     # Client capabilities specific to regular expressions.
@@ -457,7 +451,7 @@ class ClientCapabilitiesGeneral(TypedDict):
     positionEncodings: NotRequired[list[PositionEncodingKind]]
 
 
-class TextDocumentSyncClientCapabilities(TypedDict):
+class TextDocumentSyncClientCapabilities(MessageData):
     #
     # Whether text document synchronization supports dynamic registration.
     # /
@@ -485,26 +479,25 @@ class TextDocumentSyncClientCapabilities(TypedDict):
 CompletionItemTag = Literal[1]
 
 
-class CompletionClientCapabilitiesCompletionItemTagSupport(TypedDict):
+class CompletionClientCapabilitiesCompletionItemTagSupport(MessageData):
     #
     # The tags supported by the client.
     # /
     valueSet: list[CompletionItemTag]
 
 
-class CompletionClientCapabilitiesCompletionItemResolveSuport(TypedDict):
+class CompletionClientCapabilitiesCompletionItemResolveSuport(MessageData):
     #
     # The properties that a client can resolve lazily.
     # /
     properties: list[str]
 
 
-class CompletionClientCapabilitiesCompletionItemInsertTextModeSupport(
-        TypedDict):
+class CompletionClientCapabilitiesCompletionItemInsertTextModeSupport(MessageData):
     valueSet: list[InsertTextMode]
 
 
-class CompletionClientCapabilitiesCompletionItem(TypedDict):
+class CompletionClientCapabilitiesCompletionItem(MessageData):
     #
     # Client supports snippets as insert text.
     #
@@ -544,8 +537,7 @@ class CompletionClientCapabilitiesCompletionItem(TypedDict):
     #
     # @since 3.15.0
     # /
-    tagSupport: NotRequired[
-        CompletionClientCapabilitiesCompletionItemTagSupport]
+    tagSupport: NotRequired[CompletionClientCapabilitiesCompletionItemTagSupport]
 
     #
     # Client supports insert replace edit to control different behavior if
@@ -562,8 +554,7 @@ class CompletionClientCapabilitiesCompletionItem(TypedDict):
     #
     # @since 3.16.0
     # /
-    resolveSupport: NotRequired[
-        CompletionClientCapabilitiesCompletionItemResolveSuport]
+    resolveSupport: NotRequired[CompletionClientCapabilitiesCompletionItemResolveSuport]
 
     #
     # The client supports the `insertTextMode` property on
@@ -572,8 +563,7 @@ class CompletionClientCapabilitiesCompletionItem(TypedDict):
     #
     # @since 3.16.0
     # /
-    insertTextModeSupport: NotRequired[
-        CompletionClientCapabilitiesCompletionItemInsertTextModeSupport]
+    insertTextModeSupport: NotRequired[CompletionClientCapabilitiesCompletionItemInsertTextModeSupport]
 
     #
     # The client has support for completion item label
@@ -612,7 +602,7 @@ CompletionItemKind = Literal[1,  # Text
                              ]
 
 
-class CompletionClientCapabilitiesCompletionItemKind(TypedDict):
+class CompletionClientCapabilitiesCompletionItemKind(MessageData):
     #
     # The completion item kind values the client supports. When this
     # property exists the client also guarantees that it will
@@ -626,7 +616,7 @@ class CompletionClientCapabilitiesCompletionItemKind(TypedDict):
     valueSet: NotRequired[list[CompletionItemKind]]
 
 
-class CompletionClientCapabilitiesCompletionList(TypedDict):
+class CompletionClientCapabilitiesCompletionList(MessageData):
     #
     # The client supports the following itemDefaults on
     # a completion list.
@@ -640,7 +630,7 @@ class CompletionClientCapabilitiesCompletionList(TypedDict):
     itemDefaults: NotRequired[list[str]]
 
 
-class CompletionClientCapabilities(TypedDict):
+class CompletionClientCapabilities(MessageData):
     #
     # Whether completion supports dynamic registration.
     # /
@@ -652,8 +642,7 @@ class CompletionClientCapabilities(TypedDict):
     # /
     completionItem: NotRequired[CompletionClientCapabilitiesCompletionItem]
 
-    completionItemKind: NotRequired[
-        CompletionClientCapabilitiesCompletionItemKind]
+    completionItemKind: NotRequired[CompletionClientCapabilitiesCompletionItemKind]
 
     #
     # The client supports to send additional context information for a
@@ -678,7 +667,7 @@ class CompletionClientCapabilities(TypedDict):
     completionList: NotRequired[CompletionClientCapabilitiesCompletionList]
 
 
-class HoverClientCapabilities(TypedDict):
+class HoverClientCapabilities(MessageData):
     #
     # Whether hover supports dynamic registration.
     #
@@ -692,8 +681,7 @@ class HoverClientCapabilities(TypedDict):
     contentFormat: NotRequired[list[MarkupKind]]
 
 
-class SignatureHelpClientCapabilitiesSignatureInformationParameterInformation(
-        TypedDict):
+class SignatureHelpClientCapabilitiesSignatureInformationParameterInformation(MessageData):
     #
     # The client supports processing label offsets instead of a
     # simple label string.
@@ -703,7 +691,7 @@ class SignatureHelpClientCapabilitiesSignatureInformationParameterInformation(
     labelOffsetSupport: NotRequired[bool]
 
 
-class SignatureHelpClientCapabilitiesSignatureInformation(TypedDict):
+class SignatureHelpClientCapabilitiesSignatureInformation(MessageData):
     #
     # Client supports the follow content formats for the documentation
     # property. The order describes the preferred format of the client.
@@ -713,8 +701,7 @@ class SignatureHelpClientCapabilitiesSignatureInformation(TypedDict):
     #
     # Client capabilities specific to parameter information.
     #
-    parameterInformation: NotRequired[
-        SignatureHelpClientCapabilitiesSignatureInformationParameterInformation]
+    parameterInformation: NotRequired[SignatureHelpClientCapabilitiesSignatureInformationParameterInformation]
 
     #
     # The client supports the `activeParameter` property on
@@ -725,7 +712,7 @@ class SignatureHelpClientCapabilitiesSignatureInformation(TypedDict):
     activeParameterSupport: NotRequired[bool]
 
 
-class SignatureHelpClientCapabilities(TypedDict):
+class SignatureHelpClientCapabilities(MessageData):
     #
     # Whether signature help supports dynamic registration.
     #
@@ -735,8 +722,7 @@ class SignatureHelpClientCapabilities(TypedDict):
     # The client supports the following `SignatureInformation`
     # specific properties.
     #
-    signatureInformation: NotRequired[
-        SignatureHelpClientCapabilitiesSignatureInformation]
+    signatureInformation: NotRequired[SignatureHelpClientCapabilitiesSignatureInformation]
 
     #
     # The client supports to send additional context information for a
@@ -749,7 +735,7 @@ class SignatureHelpClientCapabilities(TypedDict):
     contextSupport: NotRequired[bool]
 
 
-class DeclarationClientCapabilities(TypedDict):
+class DeclarationClientCapabilities(MessageData):
     #
     # Whether declaration supports dynamic registration. If this is set to
     # `true` the client supports the new `DeclarationRegistrationOptions`
@@ -763,7 +749,7 @@ class DeclarationClientCapabilities(TypedDict):
     linkSupport: NotRequired[bool]
 
 
-class DefinitionClientCapabilities(TypedDict):
+class DefinitionClientCapabilities(MessageData):
     #
     # Whether definition supports dynamic registration.
     #
@@ -777,7 +763,7 @@ class DefinitionClientCapabilities(TypedDict):
     linkSupport: NotRequired[bool]
 
 
-class TypeDefinitionClientCapabilities(TypedDict):
+class TypeDefinitionClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is set to
     # `true` the client supports the new `TypeDefinitionRegistrationOptions`
@@ -793,7 +779,7 @@ class TypeDefinitionClientCapabilities(TypedDict):
     linkSupport: NotRequired[bool]
 
 
-class ImplementationClientCapabilities(TypedDict):
+class ImplementationClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is set to
     # `true` the client supports the new `ImplementationRegistrationOptions`
@@ -809,21 +795,21 @@ class ImplementationClientCapabilities(TypedDict):
     linkSupport: NotRequired[bool]
 
 
-class ReferenceClientCapabilities(TypedDict):
+class ReferenceClientCapabilities(MessageData):
     #
     # Whether references supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class DocumentHighlightClientCapabilities(TypedDict):
+class DocumentHighlightClientCapabilities(MessageData):
     #
     # Whether document highlight supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class DocumentSymbolClientCapabilitiesSymbolKind(TypedDict):
+class DocumentSymbolClientCapabilitiesSymbolKind(MessageData):
     #
     # The symbol kind values the client supports. When this
     # property exists the client also guarantees that it will
@@ -837,14 +823,14 @@ class DocumentSymbolClientCapabilitiesSymbolKind(TypedDict):
     valueSet: NotRequired[list[SymbolKind]]
 
 
-class DocumentSymbolClientCapabilitiesTagSupport(TypedDict):
+class DocumentSymbolClientCapabilitiesTagSupport(MessageData):
     #
     # The tags supported by the client.
     #
     valueSet: list[SymbolTag]
 
 
-class DocumentSymbolClientCapabilities(TypedDict):
+class DocumentSymbolClientCapabilities(MessageData):
     #
     # Whether document symbol supports dynamic registration.
     #
@@ -879,8 +865,7 @@ class DocumentSymbolClientCapabilities(TypedDict):
     labelSupport: NotRequired[bool]
 
 
-class CodeActionClientCapabilitiesCodeActionLiteralSupportCodeActionKind(
-        TypedDict):
+class CodeActionClientCapabilitiesCodeActionLiteralSupportCodeActionKind(MessageData):
     #
     # The code action kind values the client supports. When this
     # property exists the client also guarantees that it will
@@ -890,7 +875,7 @@ class CodeActionClientCapabilitiesCodeActionLiteralSupportCodeActionKind(
     valueSet: list[CodeActionKind]
 
 
-class CodeActionClientCapabilitiesCodeActionLiteralSupport(TypedDict):
+class CodeActionClientCapabilitiesCodeActionLiteralSupport(MessageData):
     #
     # The code action kind is supported with the following value
     # set.
@@ -898,14 +883,14 @@ class CodeActionClientCapabilitiesCodeActionLiteralSupport(TypedDict):
     codeActionKind: CodeActionClientCapabilitiesCodeActionLiteralSupportCodeActionKind
 
 
-class CodeActionClientCapabilitiesResolveSupport(TypedDict):
+class CodeActionClientCapabilitiesResolveSupport(MessageData):
     #
     # The properties that a client can resolve lazily.
     #
     properties: list[str]
 
 
-class CodeActionClientCapabilities(TypedDict):
+class CodeActionClientCapabilities(MessageData):
     #
     # Whether code action supports dynamic registration.
     #
@@ -917,8 +902,7 @@ class CodeActionClientCapabilities(TypedDict):
     #
     # @since 3.8.0
     #
-    codeActionLiteralSupport: NotRequired[
-        CodeActionClientCapabilitiesCodeActionLiteralSupport]
+    codeActionLiteralSupport: NotRequired[CodeActionClientCapabilitiesCodeActionLiteralSupport]
 
     #
     # Whether code action supports the `isPreferred` property.
@@ -963,14 +947,14 @@ class CodeActionClientCapabilities(TypedDict):
     honorsChangeAnnotations: NotRequired[bool]
 
 
-class CodeLensClientCapabilities(TypedDict):
+class CodeLensClientCapabilities(MessageData):
     #
     # Whether code lens supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class DocumentLinkClientCapabilities(TypedDict):
+class DocumentLinkClientCapabilities(MessageData):
     #
     # Whether document link supports dynamic registration.
     #
@@ -984,28 +968,28 @@ class DocumentLinkClientCapabilities(TypedDict):
     tooltipSupport: NotRequired[bool]
 
 
-class DocumentColorClientCapabilities(TypedDict):
+class DocumentColorClientCapabilities(MessageData):
     #
     # Whether document color supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class DocumentFormattingClientCapabilities(TypedDict):
+class DocumentFormattingClientCapabilities(MessageData):
     #
     # Whether formatting supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class DocumentRangeFormattingClientCapabilities(TypedDict):
+class DocumentRangeFormattingClientCapabilities(MessageData):
     #
     # Whether formatting supports dynamic registration.
     #
     dynamicRegistration: NotRequired[bool]
 
 
-class DocumentOnTypeFormattingClientCapabilities(TypedDict):
+class DocumentOnTypeFormattingClientCapabilities(MessageData):
     #
     # Whether on type formatting supports dynamic registration.
     #
@@ -1016,7 +1000,7 @@ class DocumentOnTypeFormattingClientCapabilities(TypedDict):
 PrepareSupportDefaultBehavior = Literal[1]
 
 
-class RenameClientCapabilities(TypedDict):
+class RenameClientCapabilities(MessageData):
     #
     # Whether rename supports dynamic registration.
     #
@@ -1056,14 +1040,14 @@ class RenameClientCapabilities(TypedDict):
 DiagnosticTag = Literal[1, 2]
 
 
-class PublishDiagnosticsClientCapabilitiesTagSupport(TypedDict):
+class PublishDiagnosticsClientCapabilitiesTagSupport(MessageData):
     #
     # The tags supported by the client.
     #
     valueSet: list[DiagnosticTag]
 
 
-class PublishDiagnosticsClientCapabilities(TypedDict):
+class PublishDiagnosticsClientCapabilities(MessageData):
     #
     # Whether the clients accepts diagnostics with related information.
     #
@@ -1102,7 +1086,7 @@ class PublishDiagnosticsClientCapabilities(TypedDict):
     dataSupport: NotRequired[bool]
 
 
-class FoldingRangeClientCapabilitiesFoldingRangeKind(TypedDict):
+class FoldingRangeClientCapabilitiesFoldingRangeKind(MessageData):
     #
     # The folding range kind values the client supports. When this
     # property exists the client also guarantees that it will
@@ -1112,7 +1096,7 @@ class FoldingRangeClientCapabilitiesFoldingRangeKind(TypedDict):
     valueSet: NotRequired[list[FoldingRangeKind]]
 
 
-class FoldingRangeClientCapabilitiesFoldingRange(TypedDict):
+class FoldingRangeClientCapabilitiesFoldingRange(MessageData):
 
     #
     # If set, the client signals that it supports setting collapsedText on
@@ -1123,7 +1107,7 @@ class FoldingRangeClientCapabilitiesFoldingRange(TypedDict):
     collapsedText: NotRequired[bool]
 
 
-class FoldingRangeClientCapabilities(TypedDict):
+class FoldingRangeClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration for folding range
     # providers. If this is set to `true` the client supports the new
@@ -1151,8 +1135,7 @@ class FoldingRangeClientCapabilities(TypedDict):
     #
     # @since 3.17.0
     #
-    foldingRangeKind: NotRequired[
-        FoldingRangeClientCapabilitiesFoldingRangeKind]
+    foldingRangeKind: NotRequired[FoldingRangeClientCapabilitiesFoldingRangeKind]
 
     #
     # Specific options for the folding range.
@@ -1161,7 +1144,7 @@ class FoldingRangeClientCapabilities(TypedDict):
     foldingRange: NotRequired[FoldingRangeClientCapabilitiesFoldingRange]
 
 
-class SelectionRangeClientCapabilities(TypedDict):
+class SelectionRangeClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration for selection range
     # providers. If this is set to `true` the client supports the new
@@ -1171,7 +1154,7 @@ class SelectionRangeClientCapabilities(TypedDict):
     dynamicRegistration: NotRequired[bool]
 
 
-class LinkedEditingRangeClientCapabilities(TypedDict):
+class LinkedEditingRangeClientCapabilities(MessageData):
     #
     # Whether the implementation supports dynamic registration.
     # If this is set to `true` the client supports the new
@@ -1181,7 +1164,7 @@ class LinkedEditingRangeClientCapabilities(TypedDict):
     dynamicRegistration: NotRequired[bool]
 
 
-class CallHierarchyClientCapabilities(TypedDict):
+class CallHierarchyClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is set to
     # `true` the client supports the new `(TextDocumentRegistrationOptions &
@@ -1191,7 +1174,7 @@ class CallHierarchyClientCapabilities(TypedDict):
     dynamicRegistration: NotRequired[bool]
 
 
-class SemanticTokensClientCapabilitiesRequestsFull(TypedDict):
+class SemanticTokensClientCapabilitiesRequestsFull(MessageData):
     #
     # The client will send the `textDocument/semanticTokens/full/delta`
     # request if the server provides a corresponding handler.
@@ -1199,7 +1182,7 @@ class SemanticTokensClientCapabilitiesRequestsFull(TypedDict):
     delta: NotRequired[bool]
 
 
-class SemanticTokensClientCapabilitiesRequests(TypedDict):
+class SemanticTokensClientCapabilitiesRequests(MessageData):
     #
     # The client will send the `textDocument/semanticTokens/range` request
     # if the server provides a corresponding handler.
@@ -1213,7 +1196,7 @@ class SemanticTokensClientCapabilitiesRequests(TypedDict):
     full: NotRequired[bool | SemanticTokensClientCapabilitiesRequestsFull]
 
 
-class SemanticTokensClientCapabilities(TypedDict):
+class SemanticTokensClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is set to
     # `true` the client supports the new `(TextDocumentRegistrationOptions &
@@ -1284,7 +1267,7 @@ class SemanticTokensClientCapabilities(TypedDict):
     augmentsSyntaxTokens: NotRequired[bool]
 
 
-class MonikerClientCapabilities(TypedDict):
+class MonikerClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is set to
     # `true` the client supports the new `(TextDocumentRegistrationOptions &
@@ -1294,7 +1277,7 @@ class MonikerClientCapabilities(TypedDict):
     dynamicRegistration: NotRequired[bool]
 
 
-class TypeHierarchyClientCapabilities(TypedDict):
+class TypeHierarchyClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is set to
     # `true` the client supports the new `(TextDocumentRegistrationOptions &
@@ -1304,7 +1287,7 @@ class TypeHierarchyClientCapabilities(TypedDict):
     dynamicRegistration: NotRequired[bool]
 
 
-class InlineValueClientCapabilities(TypedDict):
+class InlineValueClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration for inline
     # value providers.
@@ -1312,7 +1295,7 @@ class InlineValueClientCapabilities(TypedDict):
     dynamicRegistration: NotRequired[bool]
 
 
-class InlayHintClientCapabilitiesResolveSupport(TypedDict):
+class InlayHintClientCapabilitiesResolveSupport(MessageData):
 
     #
     # The properties that a client can resolve lazily.
@@ -1320,7 +1303,7 @@ class InlayHintClientCapabilitiesResolveSupport(TypedDict):
     properties: list[str]
 
 
-class InlayHintClientCapabilities(TypedDict):
+class InlayHintClientCapabilities(MessageData):
 
     #
     # Whether inlay hints support dynamic registration.
@@ -1334,7 +1317,7 @@ class InlayHintClientCapabilities(TypedDict):
     resolveSupport: NotRequired[InlayHintClientCapabilitiesResolveSupport]
 
 
-class DiagnosticClientCapabilities(TypedDict):
+class DiagnosticClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is set to
     # `true` the client supports the new
@@ -1350,7 +1333,7 @@ class DiagnosticClientCapabilities(TypedDict):
     relatedDocumentSupport: NotRequired[bool]
 
 
-class TextDocumentClientCapabilities(TypedDict):
+class TextDocumentClientCapabilities(MessageData):
 
     synchronization: NotRequired[TextDocumentSyncClientCapabilities]
 
@@ -1501,7 +1484,7 @@ class TextDocumentClientCapabilities(TypedDict):
     diagnostic: NotRequired[DiagnosticClientCapabilities]
 
 
-class NotebookDocumentSyncClientCapabilities(TypedDict):
+class NotebookDocumentSyncClientCapabilities(MessageData):
     #
     # Whether implementation supports dynamic registration. If this is
     # set to `true` the client supports the new
@@ -1516,7 +1499,7 @@ class NotebookDocumentSyncClientCapabilities(TypedDict):
     executionSummarySupport: NotRequired[bool]
 
 
-class NotebookDocumentClientCapabilities(TypedDict):
+class NotebookDocumentClientCapabilities(MessageData):
     #
     # Capabilities specific to notebook document synchronization
     #
@@ -1525,7 +1508,7 @@ class NotebookDocumentClientCapabilities(TypedDict):
     synchronization: NotebookDocumentSyncClientCapabilities
 
 
-class ClientCapabilities(TypedDict):
+class ClientCapabilities(MessageData):
     #
     # Workspace specific client capabilities.
     #
